@@ -81,7 +81,7 @@ class xlcv(EnchantBase):
     def read_from_buffer(buffer, flags=None, *, b64decode=False):
         """ 从二进制流读取图片
         这个二进制流指，图片以png、jpg等某种格式存储为文件时，其对应的文件编码
-    
+
         :param b64decode: 是否需要先进行base64解码
         """
         if b64decode:
@@ -130,17 +130,17 @@ class xlcv(EnchantBase):
     @staticmethod
     def to_pil_image(pic, mode=None):
         """ 我也不懂torch里这个实现为啥这么复杂，先直接哪来用，没深究细节
-    
+
         Convert a tensor or an ndarray to PIL Image. （删除了tensor的转换功能）
-    
+
         See :class:`~torchvision.transforms.ToPILImage` for more details.
-    
+
         Args:
             pic (Tensor or numpy.ndarray): Image to be converted to PIL Image.
             mode (`PIL.Image mode`_): color space and pixel depth of input data (optional).
-    
+
         .. _PIL.Image mode: https://pillow.readthedocs.io/en/latest/handbook/concepts.html#concept-modes
-    
+
         Returns:
             PIL Image: Image converted to PIL Image.
         """
@@ -243,7 +243,7 @@ class xlcv(EnchantBase):
     @staticmethod
     def imshow2(im, winname=None, flags=1):
         """ 展示窗口
-    
+
         :param winname: 未输入时，则按test1、test2依次生成窗口
         :param flags:
             cv2.WINDOW_NORMAL，0，输入2等偶数值好像也等价于输入0，可以自动拉伸窗口大小
@@ -273,15 +273,15 @@ class xlcv(EnchantBase):
     @staticmethod
     def bg_color(im, edge_size=5, binary_img=None):
         """ 智能判断图片背景色
-    
+
         对全图二值化后，考虑最外一层宽度为edge_size的环中，0、1分布最多的作为背景色
             然后取全部背景色的平均值返回
-    
+
         :param im: 支持黑白图、彩图
         :param edge_size: 边缘宽度，宽度越高一般越准确，但也越耗性能
         :param binary_img: 运算中需要用二值图，如果外部已经计算了，可以直接传入进来，避免重复运算
         :return: color
-    
+
         TODO 可以写个获得前景色，道理类似，只是最后在图片中心去取平均值
         """
         from itertools import chain
@@ -313,7 +313,7 @@ class xlcv(EnchantBase):
     @staticmethod
     def get_plot_color(im):
         """ 获得比较适合的作画颜色
-    
+
         TODO 可以根据背景色智能推导画线用的颜色，目前是固定红色
         """
         if im.ndim == 3:
@@ -357,7 +357,7 @@ class xlcv(EnchantBase):
     @staticmethod
     def circles(im, circles, color=None, thickness=1, center=False):
         """ 在图片上画圆形
-    
+
         :param im: 要作画的图
         :param circles: 要画的圆形参数 (x, y, 半径 r)
         :param color: 画笔颜色
@@ -385,7 +385,7 @@ class xlcv(EnchantBase):
     @staticmethod
     def reduce_area(im, area):
         """ 根据面积上限缩小图片
-    
+
         即图片面积超过area时，按照等比例缩小到面积为area的图片
         """
         h, w = xlcv.imsize(im)
@@ -474,7 +474,7 @@ class xlcv(EnchantBase):
     @staticmethod
     def warp(im, warp_mat, dsize=None, *, view_rate=False, max_zoom=1, reserve_struct=False):
         """ 对图像进行透视变换
-    
+
         :param im: np.ndarray的图像数据
             TODO 支持PIL.Image格式？
         :param warp_mat: 变换矩阵
@@ -533,12 +533,12 @@ class xlcv(EnchantBase):
     @staticmethod
     def pad(im, pad_size, constant_values=0, mode='constant', **kwargs):
         r""" 拓宽图片上下左右尺寸
-    
+
         基于np.pad，定制、简化了针对图片类型数据的操作
         https://numpy.org/doc/stable/reference/generated/numpy.pad.html
-    
+
         :pad_size: 输入单个整数值，对四周pad相同尺寸，或者输入四个值的list，表示对上、下、左、右的扩展尺寸
-    
+
         >>> a = np.ones([2, 2])
         >>> b = np.ones([2, 2, 3])
         >>> xlcv.pad(a, 1).shape  # 上下左右各填充1行/列
@@ -602,7 +602,7 @@ class xlcv(EnchantBase):
     @staticmethod
     def get_sub(im, pts, *, fill=0, warp_quad=False):
         """ 从src_im取一个子图
-    
+
         :param im: 原图
             可以是图片路径、np.ndarray、PIL.Image对象
             TODO 目前只支持np.ndarray、pil图片输入，返回统一是np.ndarray
@@ -969,9 +969,6 @@ class CvImg(np.ndarray):
 
 
 if __name__ == '__main__':
-    im = xlcv.read(r"C:\home\chenkunze\data\aipocr_test\01通用\accurate\3e99d47940bf9fae942c733dcdf5dbe7.jpg")
-    im = xlcv.reduce_filesize(im, 20 * 1024)
-    xlcv.write(im, 'code4101.jpg')
-    a = xlcv.to_buffer(im)
-    b = xlcv.to_buffer(im, b64encode=True)
-    print(humanfriendly.format_size(len(a)), humanfriendly.format_size(len(b)), len(b) / len(a))
+    import fire
+
+    fire.Fire()
