@@ -6,11 +6,14 @@
 
 
 """ 封装一些代码开发中常用的功能，工程组件 """
+import re
+from abc import ABC, abstractmethod
 import datetime
 import functools
 import io
 import itertools
 import json
+import logging
 import math
 import os
 import queue
@@ -20,11 +23,10 @@ import subprocess
 import sys
 import tempfile
 import threading
-from threading import Thread
 import time
 from urllib.parse import urlparse
 
-from pyxllib.prog.newbie import classproperty
+from pyxllib.prog.newbie import classproperty, EmptyWith
 
 
 def system_information():
@@ -252,9 +254,7 @@ class DictTool:
 
 class EnchantCvt:
     """ 把类_cls的功能绑定到类cls里
-
     根源_cls里的实现类型不同，到cls需要呈现的接口形式不同，有很多种不同的转换形式
-
     每个分支里，随附了getattr目标函数的一般默认定义模板
     用_self、_cls表示dst_cls，区别原cls类的self、cls标记
     """
@@ -404,19 +404,18 @@ def check_install_package(package, speccal_install_name=None, *, user=False):
         subprocess.check_call(cmds)
 
 
-def run_once(distinct_mode=False, *, limit=1):
+def run_once(distinct_mode=0, *, limit=1):
     """
-    Args:
-        distinct_mode:
-            0，默认False，不区分输入的参数值（包括cls、self），强制装饰的函数只运行一次
-            'str'，设为True或1时，仅以字符串化的差异判断是否是重复调用，参数不同，会判断为不同的调用，每种调用限制最多执行limit次
-            'id,str'，在'str'的基础上，第一个参数使用id代替。一般用于类方法、对象方法的装饰。
-                不考虑类、对象本身的内容改变，只要还是这个类或对象，视为重复调用。
-            'ignore,str'，首参数忽略，第2个开始的参数使用str格式化
-                用于父类某个方法，但是子类继承传入cls，原本id不同会重复执行
-                使用该模式，首参数会ignore忽略，只比较第2个开始之后的参数
-            func等callable类型的对象也行，是使用run_once装饰器的简化写法
-        limit: 默认只会执行一次，该参数可以提高限定的执行次数，一般用不到，用于兼容旧的 limit_call_number 装饰器
+    :param int|str distinct_mode:
+        0，默认False，不区分输入的参数值（包括cls、self），强制装饰的函数只运行一次
+        'str'，设为True或1时，仅以字符串化的差异判断是否是重复调用，参数不同，会判断为不同的调用，每种调用限制最多执行limit次
+        'id,str'，在'str'的基础上，第一个参数使用id代替。一般用于类方法、对象方法的装饰。
+            不考虑类、对象本身的内容改变，只要还是这个类或对象，视为重复调用。
+        'ignore,str'，首参数忽略，第2个开始的参数使用str格式化
+            用于父类某个方法，但是子类继承传入cls，原本id不同会重复执行
+            使用该模式，首参数会ignore忽略，只比较第2个开始之后的参数
+        func等callable类型的对象也行，是使用run_once装饰器的简化写法
+    :param limit: 默认只会执行一次，该参数可以提高限定的执行次数，一般用不到，用于兼容旧的 limit_call_number 装饰器
     Returns: 返回decorator
     """
     if callable(distinct_mode):
@@ -547,3 +546,156 @@ class Timeout:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.alarm.cancel()
+
+
+@run_once('str')
+def inject_members(from_obj, to_obj, member_list=None, *,
+                   check=False, ignore_case=False,
+                   white_list=None, black_list=None):
+    """ 将from_obj的方法注入到to_obj中
+
+    一般用于类继承中，将子类from_obj的新增的成员方法，添加回父类to_obj中
+        反经合道：这样看似很违反常理，父类就会莫名其妙多出一些可操作的成员方法。
+            但在某些时候能保证面向对象思想的情况下，大大简化工程代码开发量。
+    也可以用于模块等方法的添加
+
+    :param from_obj: 一般是一个类用于反向继承的方法来源，但也可以是模块等任意对象。
+        注意py一切皆类，一个class定义的类本质也是type类定义出的一个对象
+        所以这里概念上称为obj才是准确的，反而是如果叫from_cls不太准确，虽然这个方法主要确实都是用于class类
+    :param to_obj: 同from_obj，要被注入方法的对象
+    :param Sequence[str] member_list: 手动指定的成员方法名，可以不指定，自动生成
+    :param check: 检查重名方法
+    :param ignore_case: 忽略方法的大小写情况，一般用于win32com接口
+    :param Sequence[str] white_list: 白名单。无论是否重名，这里列出的方法都会被添加
+    :param Sequence[str] black_list: 黑名单。这里列出的方法不会被添加
+    """
+    # 1 整理需要注入的方法清单
+    dst = set(dir(to_obj))
+    if ignore_case:
+        dst = {x.lower() for x in dst}
+
+    if member_list:
+        src = set(member_list)
+    else:
+        if ignore_case:
+            src = {x for x in dir(from_obj) if (x.lower() not in dst)}
+        else:
+            src = set(dir(from_obj)) - dst
+
+    # 2 微调
+    if white_list:
+        src |= set(white_list)
+    if black_list:
+        src -= set(black_list)
+
+    # 3 注入方法
+    for x in src:
+        setattr(to_obj, x, getattr(from_obj, x))
+        if check and (x in dst or (ignore_case and x.lower() in dst)):
+            logging.warning(f'Conflict of the same name! {to_obj}.{x}')
+
+
+class LaborContractor(ABC):
+    """ 包工头，并且要保证多线程安全 """
+
+    def __init__(self, min_worker_num, max_worker_num=None, max_idle=None, lock=None):
+        """
+
+        :param min_worker_num: 初始工人数、最少待命工人数
+        :param max_worker_num: 工人上限数
+        :param int max_idle: 工人闲置上限秒数，达到指定阈值内没有工作的工人会被自动解聘
+        :param lock: 多线程的时候，为了修改安全，可以加锁
+        """
+        self.all_workers = {}  # 所有工人数据。id: worker, 最后一次执行完任务的时间
+        self.await_workers = queue.Queue()  # 待命的工人
+        self.max_worker_num = max_worker_num
+        self.max_idle = max_idle
+        if lock is None:
+            lock = EmptyWith()
+        self.lock = lock
+
+        for i in range(min_worker_num):
+            worker = self.register_recruit_worker()
+            if worker is not None:
+                self.await_workers.put(worker)
+
+        self.recruit_num = 0  # 正在招聘的数量
+
+        if max_idle:
+            # 自动监工的子进程
+            threading.Thread(target=self.check_idle).start()
+
+    def check_status(self):
+        return f'现有{len(self.all_workers)}个workers，{self.await_workers.qsize()}个待机中'
+
+    def register_recruit_worker(self):
+        """ 对recruit_worker的封装，主要供内部使用的方法 """
+        new_worker = self.recruit_worker()
+        if new_worker is not None:
+            self.all_workers[id(new_worker)] = {'last_work_time': datetime.datetime.now(),  # 最后一次出工时间
+                                                'count': 0,  # 出工次数
+                                                }
+            return new_worker
+
+    def check_idle(self):
+        """ 检查有没工人在摸鱼，开除掉 """
+        while True:
+            time.sleep(self.max_idle)
+            now = datetime.datetime.now()
+            cur_await_workers = []  # 一个个工人拎出来检查
+            while True:
+                try:
+                    worker = self.await_workers.get_nowait()
+                except queue.Empty:
+                    break
+                message = self.all_workers[id(worker)]
+                if (now - message['last_work_time']).total_seconds() >= self.max_idle:
+                    del self.all_workers[id(worker)]
+                else:
+                    cur_await_workers.append(worker)
+            # 检查完了，放工人们回去等待任务
+            for worker in cur_await_workers:
+                self.await_workers.put(worker)
+
+    @abstractmethod
+    def recruit_worker(self):
+        """ 招聘一个工人，可以返回None表示招聘失败 """
+        return
+
+    def dispatch_worker(self, check_interval=1, wait_seconds=5):
+        """ 派遣一个工人出来工作
+
+        :param check_interval: 每过多少秒检查一次是否有工人
+        :param wait_seconds: 等待多久没有工人可用，就尝试新增工人
+        """
+        # 1 在wait_seconds内尝试等待工人
+        if len(self.all_workers):
+            try:
+                return self.await_workers.get(timeout=wait_seconds)
+            except queue.Empty:
+                pass
+
+        # 2 否则尝试招聘新工人
+        # print(f'{self.recruit_num=}')
+        if len(self.all_workers) + self.recruit_num < self.max_worker_num:
+            with self.lock:
+                self.recruit_num += 1
+            new_worker = self.register_recruit_worker()
+            with self.lock:
+                self.recruit_num -= 1
+            if new_worker is not None:
+                return new_worker
+
+        # 3 再否则就要一直等下去了
+        while True:
+            x = self.await_workers.get()
+            if x:
+                return x
+            time.sleep(check_interval)
+
+    def return_worker(self, worker):
+        """ 工作完了，退回工人 """
+        self.await_workers.put(worker)
+        worker_message = self.all_workers[id(worker)]
+        worker_message['last_work_time'] = datetime.datetime.now()
+        worker_message['count'] += 1
