@@ -483,8 +483,9 @@ def chinese2digits(chinese_str):
             raise ValueError(f'input error for {chinese_str}')
         t = t.strip()
         t = t.replace('百十', '百一十')
-        common_used_numerals = {'零': 0, '一': 1, '二': 2, '两': 2, '三': 3, '四': 4, '五': 5, '六': 6, '七': 7, '八': 8, '九': 9,
-                                '十': 10, '百': 100, '千': 1000, '万': 10000, '亿': 100000000}
+        common_used_numerals = {'零': 0, '一': 1, '二': 2, '两': 2, '三': 3, '四': 4, '五': 5,
+                                '六': 6, '七': 7, '八': 8, '九': 9, '十': 10,
+                                '百': 100, '千': 1000, '万': 10000, '亿': 100000000}
         total = 0
         r = 1  # right，右边一位的值
         for i in range(len(t) - 1, -1, -1):  # 从右往左一位一位读取
